public inbox for linux-xfs@vger.kernel.org
 help / color / mirror / Atom feed
From: Christoph Hellwig <hch@lst.de>
To: Andrey Albershteyn <aalbersh@kernel.org>
Cc: linux-xfs@vger.kernel.org
Subject: [PATCH 13/25] logprint: cleanup xlog_print_trans_dquot
Date: Fri, 28 Nov 2025 07:29:50 +0100	[thread overview]
Message-ID: <20251128063007.1495036-14-hch@lst.de> (raw)
In-Reply-To: <20251128063007.1495036-1-hch@lst.de>

Re-indent, drop typedefs and invert a conditional to allow for an early
return.

Signed-off-by: Christoph Hellwig <hch@lst.de>
---
 logprint/log_misc.c | 103 ++++++++++++++++++++++++--------------------
 1 file changed, 56 insertions(+), 47 deletions(-)

diff --git a/logprint/log_misc.c b/logprint/log_misc.c
index 8cdbb7d5fe42..73dd7ab46938 100644
--- a/logprint/log_misc.c
+++ b/logprint/log_misc.c
@@ -763,59 +763,68 @@ xlog_print_trans_inode(
 }
 
 static int
-xlog_print_trans_dquot(char **ptr, int len, int *i, int num_ops)
+xlog_print_trans_dquot(
+	char			**ptr,
+	int			len,
+	int			*i,
+	int			num_ops)
 {
-    xfs_dq_logformat_t		*f;
-    xfs_dq_logformat_t		lbuf = {0};
-    struct xfs_disk_dquot	ddq;
-    xlog_op_header_t		*head = NULL;
-    int				num, skip;
+	struct xfs_dq_logformat	*f;
+	struct xfs_dq_logformat lbuf = {0};
+	struct xfs_disk_dquot	ddq;
+	struct xlog_op_header	*head = NULL;
+	int			num, skip;
 
-    /*
-     * print dquot header region
-     *
-     * memmove to ensure 8-byte alignment for the long longs in
-     * xfs_dq_logformat_t structure
-     */
-    memmove(&lbuf, *ptr, min(sizeof(xfs_dq_logformat_t), len));
-    f = &lbuf;
-    (*i)++;					/* bump index */
-    *ptr += len;
+	/*
+	 * Print dquot header region.
+	 *
+	 * memmove to ensure 8-byte alignment for the long longs in
+	 * the xfs_dq_logformat structure.
+	 */
+	memmove(&lbuf, *ptr, min(sizeof(struct xfs_dq_logformat), len));
+	f = &lbuf;
+	(*i)++;					/* bump index */
+		*ptr += len;
 
-    if (len == sizeof(xfs_dq_logformat_t)) {
-	printf(_("#regs: %d   id: 0x%x"), f->qlf_size, f->qlf_id);
-	printf(_("  blkno: %lld  len: %d  boff: %d\n"),
-		(long long)f->qlf_blkno, f->qlf_len, f->qlf_boffset);
-    } else {
-	ASSERT(len >= 4);	/* must have at least 4 bytes if != 0 */
-	printf(_("DQUOT: #regs: %d   Not printing rest of data\n"),
-		f->qlf_size);
-	return f->qlf_size;
-    }
-    num = f->qlf_size-1;
+	if (len != sizeof(struct xfs_dq_logformat)) {
+		ASSERT(len >= 4);	/* must have at least 4 bytes if != 0 */
+		printf(_("DQUOT: #regs: %d   Not printing rest of data\n"),
+			f->qlf_size);
+		return f->qlf_size;
+	}
 
-    /* Check if all regions in this log item were in the given LR ptr */
-    if (*i+num > num_ops-1) {
-	skip = num - (num_ops-1-*i);
-	num = num_ops-1-*i;
-    } else {
-	skip = 0;
-    }
+	printf(_("#regs: %d   id: 0x%x"),
+		f->qlf_size,
+		f->qlf_id);
+	printf(_("  blkno: %lld  len: %d  boff: %d\n"),
+		(long long)f->qlf_blkno,
+		f->qlf_len,
+		f->qlf_boffset);
 
-    while (num-- > 0) {
-	head = (xlog_op_header_t *)*ptr;
-	xlog_print_op_header(head, *i, ptr);
-	ASSERT(be32_to_cpu(head->oh_len) == sizeof(struct xfs_disk_dquot));
-	memmove(&ddq, *ptr, sizeof(struct xfs_disk_dquot));
-	printf(_("DQUOT: magic 0x%hx flags 0%ho\n"),
-	       be16_to_cpu(ddq.d_magic), ddq.d_type);
-	*ptr += be32_to_cpu(head->oh_len);
-    }
-    if (head && head->oh_flags & XLOG_CONTINUE_TRANS)
-	skip++;
-    return skip;
-}	/* xlog_print_trans_dquot */
+	/* Check if all regions in this log item were in the given LR ptr */
+	num = f->qlf_size - 1;
+	if (*i + num > num_ops - 1) {
+		skip = num - (num_ops - 1 - *i);
+		num = num_ops - 1 - *i;
+	} else {
+		skip = 0;
+	}
 
+	while (num-- > 0) {
+		head = (struct xlog_op_header *)*ptr;
+		xlog_print_op_header(head, *i, ptr);
+		ASSERT(be32_to_cpu(head->oh_len) ==
+			sizeof(struct xfs_disk_dquot));
+		memmove(&ddq, *ptr, sizeof(struct xfs_disk_dquot));
+		printf(_("DQUOT: magic 0x%hx flags 0%ho\n"),
+			be16_to_cpu(ddq.d_magic),
+			ddq.d_type);
+		*ptr += be32_to_cpu(head->oh_len);
+	}
+	if (head && (head->oh_flags & XLOG_CONTINUE_TRANS))
+		skip++;
+	return skip;
+}
 
 STATIC int
 xlog_print_trans_icreate(
-- 
2.47.3


  parent reply	other threads:[~2025-11-28  6:31 UTC|newest]

Thread overview: 34+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-11-28  6:29 logprint cleanups, part1 Christoph Hellwig
2025-11-28  6:29 ` [PATCH 01/25] include: remove struct xfs_qoff_logitem Christoph Hellwig
2025-11-28  6:29 ` [PATCH 02/25] logprint: remove xlog_print_dir2_sf Christoph Hellwig
2025-11-28  6:29 ` [PATCH 03/25] logprint: re-indent printing helpers Christoph Hellwig
2025-11-28  6:29 ` [PATCH 04/25] logprint: cleanup xlog_print_op_header Christoph Hellwig
2025-11-28  6:29 ` [PATCH 05/25] logprint: cleanup struct xlog_split_item handling Christoph Hellwig
2025-11-28  6:29 ` [PATCH 06/25] logprint: cleanup xlog_print_trans_header Christoph Hellwig
2025-11-28  6:29 ` [PATCH 07/25] logprint: split per-type helpers out of xlog_print_trans_buffer Christoph Hellwig
2025-11-28  6:29 ` [PATCH 08/25] logprint: cleanup xlog_print_trans_buffer Christoph Hellwig
2025-11-28  6:29 ` [PATCH 09/25] logprint: cleanup xlog_print_trans_qoff Christoph Hellwig
2025-11-28  6:29 ` [PATCH 10/25] logprint: cleanup xlog_print_trans_inode_core Christoph Hellwig
2025-12-01 18:23   ` Andrey Albershteyn
2025-12-02  7:27     ` Christoph Hellwig
2025-11-28  6:29 ` [PATCH 11/25] logprint: move xfs_inode_item_format_convert up Christoph Hellwig
2025-12-01 18:32   ` Andrey Albershteyn
2025-12-02  7:28     ` Christoph Hellwig
2025-11-28  6:29 ` [PATCH 12/25] logprint: cleanup xlog_print_trans_inode Christoph Hellwig
2025-11-28  6:29 ` Christoph Hellwig [this message]
2025-11-28  6:29 ` [PATCH 14/25] logprint: re-indent print_lseek / print_lsn Christoph Hellwig
2025-11-28  6:29 ` [PATCH 15/25] logprint: factor out a xlog_print_process_region helper Christoph Hellwig
2025-11-28  6:29 ` [PATCH 16/25] logprint: factor out a xlog_print_op helper Christoph Hellwig
2025-12-01 18:44   ` Andrey Albershteyn
2025-12-02  7:29     ` Christoph Hellwig
2025-11-28  6:29 ` [PATCH 17/25] logprint: factor out a xlog_unpack_rec_header Christoph Hellwig
2025-11-28  6:29 ` [PATCH 18/25] logprint: cleanup xlog_print_record Christoph Hellwig
2025-11-28  6:29 ` [PATCH 19/25] logprint: cleanup xlog_print_rec_head Christoph Hellwig
2025-11-28  6:29 ` [PATCH 20/25] logprint: cleanup xlog_print_rec_xhead Christoph Hellwig
2025-11-28  6:29 ` [PATCH 21/25] logprint: re-indent print_xlog_bad_* Christoph Hellwig
2025-11-28  6:29 ` [PATCH 22/25] logprint: cleanup xlog_reallocate_xhdrs Christoph Hellwig
2025-11-28  6:30 ` [PATCH 23/25] logprint: factor out a xlog_print_ext_header helper Christoph Hellwig
2025-11-28  6:30 ` [PATCH 24/25] logprint: cleanup xlog_print_extended_headers Christoph Hellwig
2025-11-28  6:30 ` [PATCH 25/25] logprint: cleanup xfs_log_print Christoph Hellwig
2025-12-01 19:03 ` logprint cleanups, part1 Andrey Albershteyn
2025-12-02  7:29   ` Christoph Hellwig

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20251128063007.1495036-14-hch@lst.de \
    --to=hch@lst.de \
    --cc=aalbersh@kernel.org \
    --cc=linux-xfs@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox